/// <reference types="node" />
import { Server } from "../Server";
import { Permission, PermissionChange, PermissionOffer, PermissionOfferResponse, User, RealmFile, UserSpecificPermission } from '../realms';
import { EventEmitter } from 'events';
export interface IPermissionServiceEventEmitter {
    on(event: 'handlePermissionChange', listener: (changeEvent: Realm.Sync.ChangeEvent) => void): this;
    on(event: 'handleUserSpecificManagementChange', listener: (changeEvent: Realm.Sync.ChangeEvent) => void): this;
}
export declare class PermissionService extends EventEmitter implements IPermissionServiceEventEmitter {
    static MANAGEMENT_REALM_REGEX: string;
    static ADMIN_REALM_REGEX: string;
    private _syncedAdminRealm;
    readonly adminRealm: Realm;
    private _syncedStarPermissionsRealm;
    readonly starPermissionsRealm: Realm;
    private privateKey;
    private publicKey;
    private dataPath;
    private logger;
    private adminTokenUser;
    private server;
    private handleManagementChangeCallback;
    private handleAdminChangeCallback;
    serverStarted(server: Server): void;
    stop(): void;
    onDemand(accessToken: string): {
        userId: string;
        affectedPermissionsCount: number;
    };
    updateOrCreateUserPermissionWithAdminPermission(userSpecificRealm: Realm, adminPermission: Permission): boolean;
    getUserByUserId(userId: string): User;
    getAllUsers(): Realm.Results<User>;
    getUserIdsWithMetadata(key: string, value: string): string[];
    getUsersByUserIds(userIds: string[]): Realm.Results<User>;
    getManagementRealmForUserId(userId: string): Realm;
    applyPermissionChangeInAdminRealm(realmFilePath: string, userId?: string, mayRead?: boolean, mayWrite?: boolean, mayManage?: boolean): void;
    getUserSpecificPermissionRealm(userId: string): Realm;
    getUserSpecificPermissionAndAssociatedRealm(realmPath: string, userId: string): {
        userSpecificPermission: UserSpecificPermission;
        userSpecificRealm: Realm;
    };
    private handleAdminRealmPermissionToReflection(changeEvent);
    private handleManagementRealmChange(changeEvent);
    handlePermissionOfferObject(permissionOffer: PermissionOffer, userId: string, realm: Realm): void;
    handlePermissionOfferResponseObject(permissionOfferResponse: PermissionOfferResponse, userId: string, realm: Realm): Promise<void>;
    handlePermissionChangeObject(permissionChange: PermissionChange, userId: string, realm: Realm): void;
    handleStarUserIdUrl(permissionChange: PermissionChange, path: string): void;
    handleStarRealmUrlForUser(permissionChange: PermissionChange, ownerUserId: string): void;
    handleStarRealmUrlForAllUsers(permissionChange: PermissionChange, ownerUserId: string): void;
    setPermissionChangesInAdminRealm(users: Realm.Results<User>, realmFiles: Realm.Results<RealmFile>, mayWrite: boolean, mayRead: boolean, mayManage: boolean, permissionChange?: PermissionChange): void;
}
